@@ -39,7 +39,7 @@ int main(int argc, char *argv[])
     */
 
     QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&viewer);
-    adaptor->setSettingsAvailable(true);
+    adaptor->setSettingsAvailable(false);//true for menu widget dialog
 
     SettingsDlg settingsdlg;
 
